# Evaluator Report

Sort by:
Student:
Roll:
File:
Dark

### Assignment 1

Roll: N/A
File: Assignment 1.xlsx
Total: 18.0/20 (90.0%)

#### Question: B10

+
Description: Value match

Assertion | Status | Score | Error
--- | --- | --- | ---
value | passed | 1.0 |
formula | passed | 1.0 |

#### Question: B11

+
Description: Value match

Assertion | Status | Score | Error
--- | --- | --- | ---
value | passed | 1.0 |
formula | passed | 1.0 |

#### Question: B12

+
Description: Value match

Assertion | Status | Score | Error
--- | --- | --- | ---
value | passed | 1.0 |
formula | passed | 1.0 |

#### Question: B13

+
Description: Value match

Assertion | Status | Score | Error
--- | --- | --- | ---
value | failed | 0.0 |
formula | passed | 1.0 |

#### Question: B14

+
Description: Value match

Assertion | Status | Score | Error
--- | --- | --- | ---
value | failed | 0.0 |
formula | passed | 1.0 |

#### Question: B5

+
Description: Value match

Assertion | Status | Score | Error
--- | --- | --- | ---
value | passed | 1.0 |
formula | passed | 1.0 |

#### Question: B6

+
Description: Value match

Assertion | Status | Score | Error
--- | --- | --- | ---
value | passed | 1.0 |
formula | passed | 1.0 |

#### Question: B7

+
Description: Value match

Assertion | Status | Score | Error
--- | --- | --- | ---
value | passed | 1.0 |
formula | passed | 1.0 |

#### Question: B8

+
Description: Value match

Assertion | Status | Score | Error
--- | --- | --- | ---
value | passed | 1.0 |
formula | passed | 1.0 |

#### Question: B9

+
Description: Value match

Assertion | Status | Score | Error
--- | --- | --- | ---
value | passed | 1.0 |
formula | passed | 1.0 |

### Assignment_1 name roll no

Roll: N/A
File: Assignment_1 name roll no.xlsx
Total: 0.0/20 (0.0%)

#### Question: B10

+
Description: Value match

Assertion | Status | Score | Error
--- | --- | --- | ---
value | failed | 0.0 |
formula | failed | 0.0 |

#### Question: B11

+
Description: Value match

Assertion | Status | Score | Error
--- | --- | --- | ---
value | failed | 0.0 |
formula | failed | 0.0 |

#### Question: B12

+
Description: Value match

Assertion | Status | Score | Error
--- | --- | --- | ---
value | failed | 0.0 |
formula | failed | 0.0 |

#### Question: B13

+
Description: Value match

Assertion | Status | Score | Error
--- | --- | --- | ---
value | failed | 0.0 |
formula | failed | 0.0 |

#### Question: B14

+
Description: Value match

Assertion | Status | Score | Error
--- | --- | --- | ---
value | failed | 0.0 |
formula | failed | 0.0 |

#### Question: B5

+
Description: Value match

Assertion | Status | Score | Error
--- | --- | --- | ---
value | failed | 0.0 |
formula | failed | 0.0 |

#### Question: B6

+
Description: Value match

Assertion | Status | Score | Error
--- | --- | --- | ---
value | failed | 0.0 |
formula | failed | 0.0 |

#### Question: B7

+
Description: Value match

Assertion | Status | Score | Error
--- | --- | --- | ---
value | failed | 0.0 |
formula | failed | 0.0 |

#### Question: B8

+
Description: Value match

Assertion | Status | Score | Error
--- | --- | --- | ---
value | failed | 0.0 |
formula | failed | 0.0 |

#### Question: B9

+
Description: Value match

Assertion | Status | Score | Error
--- | --- | --- | ---
value | failed | 0.0 |
formula | failed | 0.0 |

## Student Summary

Student | Roll Number | Marks Obtained | Out of
--- | --- | --- | ---
Assignment 1 | N/A | 18.0 | 20
Assignment_1 name roll no | N/A | 0.0 | 20